// Emacs style mode select   -*- C++ -*-
//-----------------------------------------------------------------------------
//
// $Id: r_sky.c,v 1.1.1.1 2000/04/30 19:12:08 fraggle Exp $
//
// Copyright (C) 1993-1996 by id Software, Inc.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//
//--------------------------------------------------------------------------
//
// DESCRIPTION:
//  Sky rendering. The DOOM sky is a texture map like any
//  wall, wrapping around. A 1024 columns equal 360 degrees.
//  The default sky map is 256 columns and repeats 4 times
//  on a 320 screen?
//
//-----------------------------------------------------------------------------

static const char
rcsid[] = "$Id: r_sky.c,v 1.1.1.1 2000/04/30 19:12:08 fraggle Exp $";

#include "doomstat.h"
#include "r_sky.h"
#include "r_data.h"
#include "p_info.h"

//
// sky mapping
//

int skyflatnum;
int skytexture;
int skytexturemid;
int stretchsky=1;

//
// R_InitSkyMap
// Called whenever the view size changes.
//
void R_InitSkyMap (void)
{
  skytexturemid = 100*FRACUNIT;
}

// called when the level starts to load the appropriate sky

void R_StartSky()
{
  char *texturename=0;
  // Set the sky map.
  // First thing, we have a dummy sky texture name,
  //  a flat. The data is in the WAD only because
  //  we look for an actual index, instead of simply
  //  setting one.

  skyflatnum = R_FlatNumForName ( SKYFLATNAME );

  // DOOM determines the sky texture to be used
  // depending on the current episode, and the game version.
  if (gamemode == commercial)
    // || gamemode == pack_tnt   //jff 3/27/98 sorry guys pack_tnt,pack_plut
    // || gamemode == pack_plut) //aren't gamemodes, this was matching retail
    {
        texturename="SKY3";
        if(gamemap<13) texturename="SKY1";
        else
          if(gamemap<21) texturename="SKY2";
    }
  else //jff 3/27/98 and lets not forget about DOOM and Ultimate DOOM huh?
    switch (gameepisode)
      {
      case 1:
        texturename="SKY1";
	break;
      case 2:
        texturename="SKY2";
	break;
      case 3:
        texturename="SKY3";
	break;
      case 4: // Special Edition sky
        texturename="SKY4";
	break;
      }//jff 3/27/98 end sky setting fix

  if(*info_skyname)
    texturename=info_skyname;

  skytexture = R_TextureNumForName (texturename);

}

char egg[]={247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,14,14,15,79,79,79,15,15,78,110,111,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,
247,247,247,247,247,247,247,247,247,247,14,143,14,14,15,15,15,79,79,110,110,5,5,5,111,14,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,14,14,13,14,14,14,14,14,14,78,108,108,111,5,5,5,109,14,238,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,15,14,15,14,15,9,14,14,14,78,15,13,14,109,110,5,5,110,14,14,14,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,78,15,15,14,13,78,79,79,79,15,14,15,15,15,15,109,111,5,5,109,14,13,14,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,79,111,9,110,109,9,110,5,111,109,14,15,15,15,110,110,109,5,5,111,110,110,9,109,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,79,5,5,111,111,110,109,110,5,111,111,110,110,110,110,110,109,109,111,5,110,5,5,5,5,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,111,5,5,5,5,5,111,110,5,5,5,5,5,5,5,111,111,111,111,111,5,111,5,5,5,5,5,247,247,247,247,247,247,247,
247,247,247, /*** you ain't seen me, right ? ****/ 247,247,247,247,247,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,111,5,5,5,5,247,247,247,247,247,247,247,247,247,247,247,247,247,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,111,5,5,5,5,5,247,247,247,247,247,247,247,247,247,247,247,111,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,247,247,247,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,247,247,111,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,247,247,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,247,5,5,5,5,5,5,5,5,5,5,5,5,237,236,150,14,14,142,13,15,238,79,5,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,79,5,5,5,5,5,5,5,5,5,79,236,73,72,71,139,138,136,137,139,73,236,239,5,5,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,79,239,239,5,5,5,5,5,5,5,14,148,73,73,73,73,139,137,137,138,147,140,143,15,1,5,5,5,5,5,5,5,5,
5,5,247,247,247,247,247,247,247,239,237,13,239,5,5,5,5,5,15,76,73,73,237,238,238,238,238,14,149,141,73,74,236,238,5,5,5,5,5,5,5,5,5,5,247,247,247,247,247,247,247,239,14,140,13,239,5,1,5,142,138,73,73,72,75,238,239,1,1,2,239,238,76,76,76,237,15,79,5,6,5,5,5,5,5,5,247,247,247,247,247,247,247,79,15,136,138,237,239,239,76,139,69,71,72,70,147,149,13,79,1,2,2,2,239,238,238,237,237,15,79,1,5,5,5,5,5,5,247,247,247,247,247,247,247,239,1,139,139,75,76,150,73,71,69,69,70,69,71,148,14,239,2,2,2,1,239,239,238,239,239,79,1,5,6,5,5,5,5,5,247,247,247,247,247,247,247,2,2,15,139,73,74,73,72,70,69,69,70,69,70,69,73,237,239,239,239,238,15,14,238,1,2,2,6,6,6,6,5,5,5,247,247,247,247,247,247,247,247,2,2,1,238,76,73,71,71,70,69,70,70,69,70,146,69,72,74,149,236,150,73,140,238,2,2,6,6,6,7,5,5,5,5,247,247,247,247,247,247,247,247,7,2,2,2,15,72,70,70,70,70,70,70,69,70,70,69,70,71,71,72,74,72,140,238,2,6,6,6,6,6,5,6,6,247,247,247,247,247,247,247,247,6,2,6,2,1,15,72,70,69,70,70,70,70,71,71,72,73,73,73,71,71,70,134,139,239,2,2,7,7,7,7,6,
6,247,247,247,247,247,247,247,247,6,6,6,2,2,238,150,72,70,70,70,71,71,71,72,73,74,76,44,76,71,145,132,132,138,238,79,1,2,2,6,6,247,247,247,247,247,247,247,247,247,6,6,2,2,1,15,14,75,73,72,71,71,72,72,72,73,74,76,237,237,76,71,135,131,131,147,238,238,78,79,1,79,247,247,247,247,247,247,247,247,247,247,6,2,1,79,15,143,74,75,74,73,72,72,72,73,73,74,75,76,74,73,237,238,76,138,135,139,15,15,15,78,78,247,247,247,247,247,247,247,247,247,247,247,6,2,79,142,141,73,74,76,237,75,74,73,73,73,74,74,76,76,73,148,236,239,239,239,15,238,239,239,238,78,247,247,247,247,247,247,247,247,247,247,247,247,2,239,141,139,148,73,74,237,239,15,76,74,74,73,74,237,239,239,76,140,141,15,1,2,2,1,1,79,79,238,247,247,247,247,247,247,247,247,247,247,247,247,1,142,138,147,72,74,150,238,239,239,237,150,74,74,75,76,76,76,15,238,238,238,1,6,6,5,1,1,239,247,247,247,247,247,247,247,247,247,247,247,247,247,13,136,137,147,73,75,15,238,1,1,239,237,75,74,74,73,71,71,73,76,239,2,6,6,6,5,1,1,247,247,247,247,247,247,247,247,247,247,247,247,247,247,136,
135,146,139,149,76,15,79,1,2,1,239,76,74,72,71,70,71,74,237,238,1,2,7,6,6,2,79,247,247,247,247,247,247,247,247,247,247,247,247,247,247,136,146,147,73,150,237,78,79,1,2,2,1,238,75,71,69,69,69,73,15,239,1,2,6,6,6,1,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,137,137,139,74,151,77,79,79,1,6,6,2,1,238,74,147,145,145,146,73,237,239,1,6,6,6,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,140,139,149,76,15,238,79,1,1,6,6,2,2,1,238,236,139,137,147,71,73,237,79,6,7,6,2,247,247,247,247,247,247,247,247,247,247,247,247,247,247,247,238,142,13,15,238,79,79,1,6,6,2,6,6,2,2,239,238,237,150,150,236,15,1,7,7,6,6,2,247,247,247,247,247,247,247,247,247,247,247,247,247,247,2,111,15,78,79,1,1,6,6,6,6,6,6,6,6,2,2,1,1,1,1,1,2,6,6,6,6,2,5,247,247,247,247,247,247,247,247,247,247,247,247,247,6,2,1,79,1,1,6,6,6,6,6,6,6,6,6,6,6,6,2,2,2,2,6,6,6,6,6,6,2,247,247,247,247,247,247,247,247,247,247,247,247,247};


//----------------------------------------------------------------------------
//
// $Log: r_sky.c,v $
// Revision 1.1.1.1  2000/04/30 19:12:08  fraggle
// initial import
//
//
//----------------------------------------------------------------------------
